#install.packages("phyloseq")
#install.packages("iNEXT")
library(phyloseq)
library(iNEXT)

asv_table <- read.csv("asv_table.csv", row.names = 1)
taxonomy_table <- read.csv("taxonomy_table.csv", row.names = 1)
metadata <- read.csv("metadata.csv", row.names = 1)

otu_table <- otu_table(asv_table, taxa_are_rows = TRUE)
tax_table <- tax_table(as.matrix(taxonomy_table))
sample_data <- sample_data(metadata)
physeq <- phyloseq(otu_table, tax_table, sample_data)

# Convert phyloseq object to iNEXT input format
asv_abund <- as(otu_table(physeq), "matrix")
asv_abund <- t(asv_abund)  # Transpose to match iNEXT format

# Perform rarefaction analysis
rarefaction_result <- iNEXT(asv_abund, q = 0, datatype = "abundance")

# Plot rarefaction curves
plot(rarefaction_result)
